==> haskell-language-c-0.6.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-language-c.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-c
version: 0.6.1
id: language-c-0.6.1-5gh1WohdlO0EzFoFb0yDvx
key: language-c-0.6.1-5gh1WohdlO0EzFoFb0yDvx
license: BSD3
copyright: LICENSE
maintainer: benedikt.huber@gmail.com
stability: experimental
homepage: http://visq.github.io/language-c/
synopsis: Analysis and generation of C code
description:
    Language C is a haskell library for the analysis and generation of C code.
    It features a complete, well tested parser and pretty printer for all of C99 and a large
    set of C11 and clang/GNU extensions.
category: Language
author: AUTHORS
exposed: True
exposed-modules:
    Language.C Language.C.Data Language.C.Data.Position
    Language.C.Data.Ident Language.C.Data.Error Language.C.Data.Name
    Language.C.Data.Node Language.C.Data.InputStream Language.C.Syntax
    Language.C.Syntax.AST Language.C.Syntax.Constants
    Language.C.Syntax.Ops Language.C.Syntax.Utils Language.C.Parser
    Language.C.Pretty Language.C.System.Preprocess
    Language.C.System.GCC Language.C.Analysis
    Language.C.Analysis.ConstEval Language.C.Analysis.Builtins
    Language.C.Analysis.SemError Language.C.Analysis.SemRep
    Language.C.Analysis.DefTable Language.C.Analysis.TravMonad
    Language.C.Analysis.AstAnalysis Language.C.Analysis.DeclAnalysis
    Language.C.Analysis.Debug Language.C.Analysis.TypeCheck
    Language.C.Analysis.TypeConversions Language.C.Analysis.TypeUtils
    Language.C.Analysis.NameSpaceMap Language.C.Analysis.Export
hidden-modules: Language.C.Data.RList Language.C.Parser.Builtin
                Language.C.Parser.Lexer Language.C.Parser.ParserMonad
                Language.C.Parser.Tokens Language.C.Parser.Parser
abi: 9b52b7088d0c76d5463de4c03206ace3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/language-c-0.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/language-c-0.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/language-c-0.6.1
hs-libraries: HSlanguage-c-0.6.1-5gh1WohdlO0EzFoFb0yDvx
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    directory-1.2.6.2 filepath-1.4.1.0 pretty-1.1.3.3 process-1.4.2.0
    syb-0.6-C65vWCsht6A8uLstpQIXyj
haddock-interfaces: /usr/share/doc/haskell-language-c/html/language-c.haddock
haddock-html: /usr/share/doc/haskell-language-c/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-c-0.6.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-language-c.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-c
version: 0.6.1
id: language-c-0.6.1-Ie0cyE3tcnqDNsl2eKF0Tp
key: language-c-0.6.1-Ie0cyE3tcnqDNsl2eKF0Tp
license: BSD3
copyright: LICENSE
maintainer: benedikt.huber@gmail.com
stability: experimental
homepage: http://visq.github.io/language-c/
synopsis: Analysis and generation of C code
description:
    Language C is a haskell library for the analysis and generation of C code.
    It features a complete, well tested parser and pretty printer for all of C99 and a large
    set of C11 and clang/GNU extensions.
category: Language
author: AUTHORS
exposed: True
exposed-modules:
    Language.C Language.C.Data Language.C.Data.Position
    Language.C.Data.Ident Language.C.Data.Error Language.C.Data.Name
    Language.C.Data.Node Language.C.Data.InputStream Language.C.Syntax
    Language.C.Syntax.AST Language.C.Syntax.Constants
    Language.C.Syntax.Ops Language.C.Syntax.Utils Language.C.Parser
    Language.C.Pretty Language.C.System.Preprocess
    Language.C.System.GCC Language.C.Analysis
    Language.C.Analysis.ConstEval Language.C.Analysis.Builtins
    Language.C.Analysis.SemError Language.C.Analysis.SemRep
    Language.C.Analysis.DefTable Language.C.Analysis.TravMonad
    Language.C.Analysis.AstAnalysis Language.C.Analysis.DeclAnalysis
    Language.C.Analysis.Debug Language.C.Analysis.TypeCheck
    Language.C.Analysis.TypeConversions Language.C.Analysis.TypeUtils
    Language.C.Analysis.NameSpaceMap Language.C.Analysis.Export
hidden-modules: Language.C.Data.RList Language.C.Parser.Builtin
                Language.C.Parser.Lexer Language.C.Parser.ParserMonad
                Language.C.Parser.Tokens Language.C.Parser.Parser
abi: 3d6efac215d3bf21fef114a5b805b7fa
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/language-c-0.6.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/language-c-0.6.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/language-c-0.6.1
hs-libraries: HSlanguage-c-0.6.1-Ie0cyE3tcnqDNsl2eKF0Tp
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    directory-1.3.0.0 filepath-1.4.1.1 pretty-1.1.3.3 process-1.4.3.0
    syb-0.6-IcoSwlPi2Nx4zSqMmorFPS
haddock-interfaces: /usr/share/doc/haskell-language-c/html/language-c.haddock
haddock-html: /usr/share/doc/haskell-language-c/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
